@@ -168,10 +168,10 @@ class Serialize:
                     field_value = float(field_value)
 
                 elif isinstance(field_value, datetime):
-                    instance_dict[field.name] = datetime.isoformat(field_value)
+                    instance_dict[field] = datetime.isoformat(field_value)
 
                 elif isinstance(field_value, date):
-                    instance_dict[field.name] = date.isoformat(field_value)
+                    instance_dict[field] = date.isoformat(field_value)
 
                 instance_dict[field] = field_value
 
